import pygame, sys, os
import random, math
import data, gui
from pygame.locals import *

offset = (0, 0)
def pp_collision(sp1, sp2):
    '''Pixel perfect collision detection given
    two sprites'''
    global offset
    rect1 = sp1.rect;     
    rect2 = sp2.rect;                            
    rect  = rect1.clip(rect2)
    x1 = rect.x-rect1.x
    y1 = rect.y-rect1.y
    x2 = rect.x-rect2.x
    y2 = rect.y-rect2.y
    for r in xrange(0, rect.height):      
        for c in xrange(0, rect.width):
            if sp1.image.get_at((c+x1, r+y1))[3] > 250 and sp2.image.get_at((c+x2, r+y2))[3] > 250:
                offset = (c, r)
                return True
    return False

class RhythmInput:
    images = data.load_img("button.png") #pygame.image.load("button.png")
    lh_keys = 'qwertasdfgzxcv'
    rh_keys = 'yuiophjklnm'
    #pos = ([(40, 100), (40, 80), (40, 50) ], [(560, 100), (560, 80), (560, 50)])
    pos = ((40, 100), (40, 80), (40, 50), (560, 100), (560, 80), (560, 50))
    def __init__(self):
        self.interval = 40
        self.timer = 0
        self.font = pygame.font.SysFont("Times", 30)
        self.key_domain = 'asd' 
        #self.key_string = None
        #self.marker = None
        self.max_count = 3
        self.pos_index = 0
        self.key_pos = RhythmInput.pos[self.pos_index]
        self.set_keys()

    def set_key_domain(self, keys, count, interval = 40):
        self.key_domain = keys
        self.max_count = count
        self.interval = interval

    def set_keys(self):
        '''Randomized generation of keys''' 
        self.keys = []
        self.key_score = []
        str = ''
        for i in xrange(self.max_count):
            self.keys.append(' ')
            self.keys.append(random.choice(self.key_domain))
            #tmp = random.choice(self.key_domain)
            #self.keys.append(tmp)
            #str += ' ' + tmp 
            self.key_score.append(0)
            self.key_score.append(0)
        self.keys.append(' ')
        self.key_score.append(0)
        #self.keys = [' ', 'a', ' ', 's', ' ', 'd']
        #self.key_score = [0, 0, 0, 0, 0, 0]
        self.cur = 0
        self.done = False
        #self.key_count = self.max_count #level * 3#len(self.keys)/2
        self.char = self.font.render(self.keys[self.cur], True, (255, 255, 255))
        #self.key_string = self.font.render(str, True, (255, 255, 255))
        #self.font.set_bold(True)
        #self.marker = self.font.render('^', True, (255, 0, 0))
        #self.font.set_bold(False)

    def is_done(self):
        return self.done

    def get_accuracy(self):
        return int(float(sum(self.key_score))/(len(self.keys)/2) * 100)

    def update(self):
        self.timer += 1
        if( self.timer > self.interval-1 ):
            self.cur += 1
            self.timer = 0
            if( self.cur > len(self.keys)-1 ):
                self.done = True
                return
            self.char = self.font.render(self.keys[self.cur], True, (255, 255, 255))
            #if self.keys[self.cur] in RhythmInput.lh_keys:
            #    self.key_pos = random.choice(RhythmInput.pos[0])
            #elif self.keys[self.cur] in RhythmInput.rh_keys:
            #    self.key_pos = random.choice(RhythmInput.pos[1])

    def draw(self, scr):                
        #left = 320 -  self.key_string.get_width()/2
        #scr.blit(self.key_string, (left, 400))
        #draw marker
        #scr.blit(self.marker, (left + (self.cur/2)*20,440))
        if self.done or len(self.keys)-1 == self.cur:
            return
        if self.cur % 2 == 0: 
            if self.timer == 0:
                self.pos_index += 1
                self.pos_index %= len(RhythmInput.pos)
                self.key_pos = RhythmInput.pos[self.pos_index]
            #pygame.draw.circle(scr, (0, 0, 0), (320, 50), 60-self.timer, 2)
            pygame.draw.circle(scr, (0, 0, 0), (self.key_pos[0]+10, self.key_pos[1]+20), self.interval+20-self.timer, 2)
            #key_pos[0] + 10, key_pos[1] + 20
            tmp = self.font.render(self.keys[self.cur+1], True, (0, 0, 0))
            scr.blit(tmp, self.key_pos)
            return 
        #pygame.draw.circle(scr, (0, 5, 0), (50, 125), 20, 2)
        #scr.blit(RhythmInput.images, (32, 102))
        #scr.blit(self.char, (40, 100))
        scr.blit(RhythmInput.images, (self.key_pos[0]-8, self.key_pos[1]+2))
        scr.blit(self.char, self.key_pos)

    def pressed(self, key):
        if self.done:# or self.key_count == 0: 
            return False
        if(self.keys[self.cur] == key):
            self.key_score[self.cur] = 1
            #self.key_count -= 1 
            return True
        else:
            if self.keys[self.cur] == ' ':
                self.cur += 2
                if self.cur < len(self.keys):
                    self.timer = 0
                    self.char = self.font.render(self.keys[self.cur], True, (255, 255, 255))
                else:
                    self.done = True
            return False
            #self.key_score[self.cur] = -1
            
class Model:
    def __init__(self, type):
        self.all_frames = []
        self.anims = {}
        if type == 'explosion':
            self.all_frames.append(data.load_img("exp_1.png"))
            #self.all_frames.append(data.load_img("exp_2.png"))
            #self.all_frames.append(data.load_img("exp_3.png"))
            self.anims['idle'] = (0, 1)
            self.anims['attack'] = (0, 1)
            self.anims['run'] = (0, 1)
        elif type == 'human':
            self.all_frames.append(data.load_img("m_i1.png"))
            self.all_frames.append(data.load_img("m_i2.png"))
            self.all_frames.append(data.load_img("m_i3.png"))
            self.all_frames.append(data.load_img("m_r1.png"))
            self.all_frames.append(data.load_img("m_r2.png"))
            self.all_frames.append(self.all_frames[3])
            self.all_frames.append(self.all_frames[4])
            self.all_frames.append(data.load_img("m_t1.png"))
            self.all_frames.append(data.load_img("m_t2.png"))
            self.all_frames.append(data.load_img("m_t3.png"))
            self.anims['idle'] = (0, 3)
            self.anims['run'] = (3, 7)
            self.anims['attack'] = (7, 10)        
        elif type == '3':
            self.all_frames.append(data.load_img("e3_i1.png"))
            self.all_frames.append(data.load_img("e3_i2.png"))
            self.all_frames.append(data.load_img("e3_i3.png"))
            self.anims['idle'] = (0, 3)
            self.anims['attack'] = (0, 3)
            self.anims['run'] = (0, 3)
        elif type == '2':
            self.all_frames.append(data.load_img("e2_i1.png"))
            self.all_frames.append(data.load_img("e2_a2.png"))
            self.all_frames.append(data.load_img("e2_a3.png"))
            self.all_frames.append(data.load_img("e2_a4.png"))
            self.anims['idle'] = (0, 1)
            self.anims['attack'] = (0, 4)
            self.anims['run'] = (0, 1)
        elif type == '1':
            self.all_frames.append(data.load_img("e1_i1.png"))
            self.all_frames.append(data.load_img("e1_i2.png"))
            self.all_frames.append(data.load_img("e1_i3.png"))
            self.anims['idle'] = (0, 3)
            self.anims['attack'] = (0, 3)
            self.anims['run'] = (0, 3)
        else:
            self.all_frames.append(data.load_img(type+".png"))
            self.anims['idle'] = (0, 1)
            self.anims['attack'] = (0, 1)
            self.anims['run'] = (0, 1)

    def start_frame(self, anim):
        return self.anims[anim][0]

    def get_y(self, index = 0):
        return 377-self.all_frames[index].get_height()

    def end_frame(self, anim):
        return self.anims[anim][1]

    def get_frame(self, index):
        return self.all_frames[index]

class Anim:
    def __init__(self, model):
        self.cur_frame = 0
        self.frame_time = 10
        self.cur_anim = 'idle'
        self.timer = 0
        self.model = model

    def set_anim(self, anim):
        self.cur_anim = anim
        start = self.model.start_frame(self.cur_anim) 
        end = self.model.end_frame(self.cur_anim) 
        self.cur_frame = start #random.randint(start, end-1)
        if anim == 'idle':
            self.cur_frame = random.randint(start, end-1)
        self.timer = 0

#    def draw(self, scr, pos):
#        scr.blit(self.model.get_frame(self.cur_frame), pos)

    def get_frame(self):
        return self.model.get_frame(self.cur_frame)
    def get_y(self):
        return self.model.get_y(self.cur_frame)

    def update(self):
        self.timer += 1
        if self.timer > self.frame_time:
            self.timer = 0
            self.cur_frame += 1
            self.cur_frame %= self.model.end_frame(self.cur_anim) 

class Explosion(Anim, pygame.sprite.Sprite):
    def __init__(self, pos):
        Anim.__init__(self, Model('explosion'))
        pygame.sprite.Sprite.__init__(self)
        self.image = self.get_frame()
        self.rect = self.image.get_rect()
        self.rect.left = pos[0]
        self.rect.top = pos[1]

    def update(self):
        self.timer += 1
        if self.timer > self.frame_time:
            self.timer = 0
            self.cur_frame+= 1
            if self.cur_frame < self.model.end_frame('idle'):
                self.image = self.get_frame()                
            else:
                self.kill()

class RealObject(pygame.sprite.Sprite):
    gravity = .1
    max_vel = 5
    images = []
    def __init__(self, pos, vel):
        pygame.sprite.Sprite.__init__(self)
        if len(RealObject.images) == 0:
            RealObject.images.append(data.load_img("bullet.png"))
        self.angle = 0
        self.x = pos[0]
        self.y = pos[1]
        self.vx = vel[0]
        self.vy = vel[1]
        self.img_index = 0 #gen this random? or just get a param
        self.image = RealObject.images[self.img_index]
        self.rect = self.image.get_rect()
        self.rect.left = self.x
        self.rect.top = self.y
        self.interval = 50
        self.timer = 0

    def cal_angle(self):
        len = math.sqrt(self.vx * self.vx + self.vy * self.vy)
        vec = (self.vx/ len, -1*self.vy/len) 
        if(vec[0]):
            self.angle = math.degrees(math.atan(vec[1]/vec[0])) - vec[0]/math.fabs(vec[0]) *90
        else:
            if(vec[1] > 0):
                self.angle = 0
            else:
                self.angle = 180

    def update(self):
        #update the velocity and position
        if self.x > 640 or self.x < 0:
            self.kill()
        if self.y > 385 - self.rect.height:
            self.timer += 1
            if self.timer > self.interval:
                self.kill()
            return

        self.x = self.vx + self.x
        self.y = self.vy + self.y

        self.vy = self.vy + RealObject.gravity
        if self.vy > self.max_vel:
            self.vy = self.max_vel
        #calculate the angle of the object            
        self.cal_angle()
        #set the image, position for the sprite.
        img = RealObject.images[self.img_index]
        self.image = pygame.transform.rotate(img, self.angle)
        self.rect = self.image.get_rect()
        self.rect.left = self.x
        self.rect.top = self.y

                   

class Unit(pygame.sprite.Sprite):
    def __init__(self, model, xval = 0):
        pygame.sprite.Sprite.__init__(self)
        self.health = 100
        self.interval = 100 #interval to change the action
        self.timer = 0
        self.x = xval #random.randrange(10, 100, 40)
        self.y = model.get_y()#315
        self.data = Anim(model) 
        self.is_attacking = False
        #------------------------
        self.image = self.data.get_frame()
        self.rect = self.image.get_rect()
        self.rect.left = self.x
        self.rect.top = self.y
        self.act_list = ['idle']                
        #------------------------
        #enemy requirements
        self.vx = random.randint(1, 5)
        self.dest_x = 0
        self.is_enemy = False
        self.enemy_id = 0

    def init_enemy(self, dest_x, enemy_id = 3):
        self.dest_x = dest_x
        self.x = 640
        self.is_enemy = True
        self.rect.left = self.x
        self.act_list = ['idle', 'attack']                
        self.health = 150
        self.enemy_id = enemy_id
        
    def set_actlist(self, list):
        self.act_list = list

    def set_anim(self, name):
        self.data.set_anim(name)

    def gen_anim(self):
        choice = random.choice(self.act_list)
        self.data.set_anim(choice)
        if choice == 'attack':
            self.is_attacking = True
        else:
            self.is_attacking = False
        #self.data.set_anim('run')

#    def draw(self, scr):
#        self.data.draw(scr, (self.x, self.y))

    def update(self):
        if self.is_enemy:
            if self.x > self.dest_x:
                self.x -= self.vx
            elif self.x + 50 < self.dest_x:
                self.x += self.vx
        self.timer += 1
        if self.timer > self.interval:
            self.timer = 0
            self.gen_anim()
        self.data.update()            
        #--------------------------
        self.image = self.data.get_frame()
        self.rect = self.image.get_rect()
        self.rect.left = self.x
        self.rect.top = self.y
        #--------------------------
        return self.is_attacking

class Game:
    def __init__(self):
        self.combo_count = 0
        self.interval = 100 #anim interval 
        self.timer = 0
        self.level = 1
        self.world_x = 0
        self.smoke = pygame.sprite.Group()
        self.bullets = pygame.sprite.Group()
        self.enemy_bullets = pygame.sprite.Group()
        self.units = pygame.sprite.Group()
        self.enemies = pygame.sprite.Group()
        self.level_complete = False
        #-----------------
        pygame.init()
        pygame.font.init()
        self.scr_surf = pygame.display.set_mode((640, 480))
        self.rhin = RhythmInput()
        self.clock = pygame.time.Clock()
        self.cur_action = 'run'
        self.font_big = data.load_font("cajunboogie.ttf", 30)
        self.font_small = data.load_font("cajunboogie.ttf", 25)
        self.font = self.font_big
        self.hud_interval = 50
        self.hud_timer = 0
        #self.hud_keys = None
        self.combo_color = (0, 0, 0)
        #-----------------
        #sound
        #self.bg_sound = data.load_music("Ant_Marc-Dave_Gir-212.ogg")
        #self.bg_sound = data.load_music("Track07.ogg")
        #self.bg_sound = data.load_music("TNRG_Trance_Synth_051.ogg")
        self.bg_sound = data.load_music("PLP_Jungle_Bass_01.ogg")
        pygame.mixer.music.set_volume(0.5)
        pygame.mixer.music.play(-1)
        self.blast_sound = None
        #self.correct_key = (data.load_sound("chime.wav") , data.load_sound("chime.wav"))
        self.correct_key = data.load_sound("chime.wav")
#        self.m_index = 0
        self.correct_key.set_volume(0.5)
        self.wrong_key = data.load_sound("wrong.wav")
        #opening screen
        self.screen_alpha = 255
        self.alpha_timer = 0
        #menu interaction
        self.game_started = False

    def load_level(self):
        self.screen_alpha = 255
        self.combo_count = 0
        self.alpha_timer = 0
        self.timer = 0
        self.world_x = 0
        self.level_complete = False
        self.bullets.empty()
        self.enemy_bullets.empty()
        self.units.empty()
        self.enemies.empty()
        self.cur_action = 'run'
        fname = 'l' + str(self.level) + '.txt'
        fin = data.load_level(fname)
        lines = fin.readlines()
        fin.close()
        tmp = lines[0].split(' ')
        num_units = int(tmp[0])
        human = Model('human') #robot model
        for i in xrange(num_units):
            obj = Unit(human, int(tmp[i+1]))
            #self.units.add(Unit(human))
            self.units.add(obj)

        enmy_model = []
        enmy_model.append(Model('1'))
        enmy_model.append(Model('2'))
        enmy_model.append(Model('3'))
        enmy_model.append(Model('enemy1'))
        tmp = lines[1].split(' ')
        for i in xrange(len(tmp)):
            #self.enemies.add(Unit(enmy_model[int(tmp[i])-1]))
            obj = Unit(enmy_model[int(tmp[i])-1])
            if int(tmp[i]) == 3:
                obj.init_enemy(250+i*100, 3)
            elif int(tmp[i]) == 2:
                obj.init_enemy(i*10, 2)
            elif int(tmp[i]) == 1:
                obj.init_enemy(250+i*100, 1)
            else:
                obj.init_enemy(250+i*100, 4)

            #obj.x = int(lines[2]) + 200
            self.enemies.add(obj)

        #num_enemies = int(lines[1])
        self.dest_x = int(lines[2]) 
        self.bg1 = data.load_img(lines[3][:-1])
        self.bg2 = data.load_img(lines[4][:-1])
        self.bg2_scroll = 0
        self.bg3 = data.load_img(lines[5][:-1])
        self.bg3_scroll = 0
        tmp = lines[6].split(' ')
        self.rhin.set_key_domain(tmp[0], int(tmp[1]), int(tmp[2]))
        self.rhin.set_keys()

    def add_bullet(self, pos, type = 'user'):
        if type == 'user':
            vel = (random.randint(3, 5), random.randint(-8, -3))
            tmp = RealObject(pos, vel)
            self.bullets.add(tmp)
        else:
            vel = (random.randint(-5, -2), random.randint(-4, -2))
            tmp = RealObject(pos, vel)
            #self.bullets.add(tmp)
            self.enemy_bullets.add(tmp)

    def run(self):
        while 1:
            self.clock.tick(60)    
            #self.scr_surf.fill((255, 255, 255, 255), (0, 0, 640, 410))
            #self.scr_surf.fill((0, 0, 0, 255), (0, 410, 640, 480))
            self.scr_surf.blit(self.bg1, (0, 0))
            self.scr_surf.blit(self.bg2, (self.bg2_scroll, 376-self.bg2.get_height()))
            self.scr_surf.blit(self.bg2, (self.bg2_scroll+640, 376-self.bg2.get_height()))
            self.scr_surf.blit(self.bg3, (self.bg3_scroll, 376-self.bg3.get_height()))
            self.scr_surf.blit(self.bg3, (self.bg3_scroll+640, 376-self.bg3.get_height()))
            self.kb_handle(self.rhin)
            self.draw()
            self.update()
            pygame.display.flip()
    
    def update(self):
        global offset #for explosions 
        if not(self.game_started):
            msg = gui.MessageBox(['Start'], self.font_big, self.scr_surf)
            msg.show()
            self.game_started = True
            return

        if len(self.units) < 3:
            msg = gui.MessageBox(['Too many Cassualities', 'Restart Level'], self.font_big, self.scr_surf)
            msg.show()
            self.load_level()

        if len(self.enemies) == 0:
            msg = gui.MessageBox(['Level Complete', 'Continue'], self.font_big, self.scr_surf)
            msg.show()
            self.level+= 1
            if self.level > 6:
                msg = gui.MessageBox(['Congratulations!!!', 'You have Won'], self.font_big, self.scr_surf)
                msg.show()
                self.level = 1
            self.load_level()

        #blending in of the screen
        if( self.alpha_timer < self.interval):
            self.alpha_timer += 1
            self.screen_alpha -= 2
            return 
        if self.alpha_timer > self.interval:
            self.screen_alpha = 0
        #game updates
        self.bullets.update()
        self.smoke.update()
        self.enemy_bullets.update()
        if self.cur_action == 'attack': 
            #self.enemies.update()
            for enemy in self.enemies.sprites():
                if enemy.update():
                    if enemy.enemy_id == 2:
                        for unit in self.units.sprites():
                            if pp_collision(unit, enemy):
                                unit.health -= 20
                                enemy.is_attacking = False                                
                    if enemy.enemy_id == 1:
                        if len(self.enemy_bullets) < 8:
                            self.add_bullet((enemy.x, enemy.y), 'adf')
                        #self.add_bullet((enemy.x, enemy.y), 'adf')
                        #self.add_bullet((enemy.x, enemy.y), 'adf')
                        #self.add_bullet((enemy.x, enemy.y), 'adf')
                        #enemy.is_attacking = False

                #collision between enemy units and bullets                    
                obj_list = pygame.sprite.spritecollide(enemy, self.bullets, False)
                for obj in obj_list:
                    if pp_collision(obj, enemy):
                        self.smoke.add(Explosion((obj.x+offset[0], obj.y+offset[1]/2)))
                        obj.kill()
                        enemy.health -= 5
                        if enemy.enemy_id == 2:
                            enemy.dest_x = random.randint(50, 100)
                        else:                            
                            enemy.dest_x = random.randint(250, 500)
                if enemy.health < 1:
                    enemy.kill()
            if len(self.enemies.sprites()) == 0:
                self.level_complete = True
        #units.update()
        for unit in self.units.sprites():
            if unit.update():
                unit.is_attacking = False
                self.add_bullet((unit.x, unit.y))
            #collision between user units and enemy bullets
            obj_list = pygame.sprite.spritecollide(unit, self.enemy_bullets, False)
            for obj in obj_list:
                if pp_collision(obj, unit):
                    obj.kill()
                    unit.health -= 5
            if unit.health < 1:
                unit.kill()

        self.rhin.update()
        if self.rhin.is_done():
            accr = self.rhin.get_accuracy()
            #timer is 0 for the first time
            if self.timer == 0:
                if self.world_x < self.dest_x:
                    self.cur_action = 'run'
                else:
                    self.cur_action = 'attack'
                #handling combos 
                if accr == 100:
                    self.combo_count += 1
                else:
                    self.combo_count = 0
                #handling the walk animation
                for unit in self.units.sprites():
                    if self.cur_action == 'attack':
                        if self.combo_count > 5:
                            self.rhin.interval = 30
                            unit.set_actlist([self.cur_action])
                        elif self.combo_count > 2:                            
                            unit.set_actlist([self.cur_action, 'idle', 'idle'])
                            self.rhin.interval = 35
                        else:
                            unit.set_actlist([self.cur_action, 'idle', 'idle', 'idle', 'idle'])

                    else:                        
                        unit.set_actlist([self.cur_action])
                        unit.set_anim(self.cur_action)

            #if rhythm input is done, start moving the platforms
            if self.cur_action == 'run':
                self.bg2_scroll -= 2 * accr /100
                self.bg3_scroll -= 5 * accr / 100
                self.world_x += 5 * accr/100

                if self.bg2_scroll < -640:
                    self.bg2_scroll = 0
                if self.bg3_scroll < -640:
                    self.bg3_scroll = 0

            self.timer += 1
            if self.timer > (self.interval - self.combo_count * 5): # - self.combo_count * 5):
                self.timer = 0
                self.rhin.set_keys()
#                self.m_index = 0
                if self.cur_action == 'run':    #this is for that feel for dance with drum
                    for unit in self.units.sprites():
                        unit.set_actlist(['idle'])
                        unit.set_anim('idle')

    def draw_hud(self):
        #self.scr_surf.blit(self.hud_keys, (0, 400))           
        if self.combo_count < 5:
            self.font.set_bold(True)
            combo_txt = self.font.render(str(self.combo_count), True, self.combo_color)
            self.scr_surf.blit(combo_txt, (25 - combo_txt.get_width(), 30 - combo_txt.get_height()))
            self.font.set_bold(False)
            combo_txt = self.font_big.render("Combo", True, (0, 0, 0))          
            self.scr_surf.blit(combo_txt, (25, 0))
        else:
            combo_txt = self.font.render("FEVER!!", True, self.combo_color)
            self.scr_surf.blit(combo_txt, (0, 0))

        self.hud_timer += 1
        if self.hud_timer > self.hud_interval:
            self.hud_timer = 0
            self.combo_color = (random.randint(0, 255), random.randint(0, 255), random.randint(0, 255))
            self.font = random.choice([self.font_big, self.font_small])

    def draw(self):
        self.units.draw(self.scr_surf)
        if self.cur_action == 'attack': 
            self.enemies.draw(self.scr_surf)
            self.enemy_bullets.draw(self.scr_surf)
        self.bullets.draw(self.scr_surf)
        self.smoke.draw(self.scr_surf)
        self.draw_hud()
        if self.alpha_timer < self.interval:
            tmp = pygame.surface.Surface((640, 480))
            tmp.fill((0, 0, 0, 255))
            tmp.set_alpha(self.screen_alpha)
            self.scr_surf.blit(tmp, (0, 0))
        else:            
            self.rhin.draw(self.scr_surf)
#            self.scr_surf.set_alpha(self.screen_alpha)
#            self.scr_surf.fill((0, 0, 0, 30), (0, 0, 640, 480))
    
    def kb_handle(self, rhin):
        for event in pygame.event.get():
            if event.type == QUIT:
                pygame.quit()
                sys.exit()
            if event.type == KEYDOWN:
                if event.key == K_ESCAPE:
                    msg = gui.MessageBox(['Game Paused'], self.font_big, self.scr_surf)
                    msg.show()
                    #pygame.font.quit()
                    #pygame.quit()
                    #sys.exit()
                else:
                    key_name = pygame.key.name(event.key)
                    if self.rhin.pressed(key_name):
                        self.correct_key.play()
#                        self.correct_key[self.m_index].play()
                        #self.m_index += 1
                        #self.m_index %= len(self.correct_key)
                    else:
                        self.wrong_key.play()


#if __name__ == "__main__":
def main():
    game = Game()
    game.load_level()
    game.run()
